@@ -6,7 +6,7 @@ import torch
 from torch._utils import _accumulate
 import matplotlib.pyplot as plt
 import matplotlib as mpl
-import femnist
+from fedbase.utils import femnist
 import os
 import pickle
 import datetime as d
